=========
SmartAgro
=========


.. image:: https://img.shields.io/pypi/v/smartagro.svg
        :target: https://pypi.python.org/pypi/smartagro

.. image:: https://travis-ci.com/chris-kck/SmartAgro.svg?branch=master
        :target: https://travis-ci.com/chris-kck/SmartAgro

.. image:: https://readthedocs.org/projects/smartagro/badge/?version=latest
        :target: https://smartagro.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://img.shields.io/badge/language-python-yellow.svg?style=flat-square
     :target: #
     :alt: Python Language

.. image:: https://img.shields.io/badge/License-GPLv3-green.svg?style=flat-square
     :target: #
     :alt: Python Language



Smart, Iot-enabled greenhouse monitoring and control API


* Free software: GNU General Public License v3
* Documentation: https://smartagro.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
